@@ -43,12 +43,12 @@
 // KDE-includes
 #include <kprocess.h>
 #include <kurl.h>
-#include <kapplication.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeapplication.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <kstandarddirs.h>
-#include <kio/global.h>
+#include <tdeio/global.h>
 #include <kdebug.h>
 
 #include <iostream>
@@ -145,7 +145,7 @@ void K3bAudioDoc::setLastTrack( K3bAudioTrack* track )
 }
 
 
-KIO::filesize_t K3bAudioDoc::size() const 
+TDEIO::filesize_t K3bAudioDoc::size() const 
 {
   // This is not really correct but what the user expects ;)
   return length().mode1Bytes();
