@@ -53,17 +53,17 @@
 #include <tqapplication.h>
 
 #include <kprogress.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <klistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdelistview.h>
 #include <kiconloader.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <kglobal.h>
+#include <tdeglobal.h>
 #include <knotifyclient.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kmainwindow.h>
+#include <tdeapplication.h>
+#include <tdemainwindow.h>
 #include <kstdguiitem.h>
 #include <kpushbutton.h>
 
@@ -155,7 +155,7 @@ void K3bJobProgressDialog::setupGUI()
   // ------------------------------------------------------------------------------------------
 
 
-  m_viewInfo = new KListView( this, "m_viewInfo" );
+  m_viewInfo = new TDEListView( this, "m_viewInfo" );
   m_viewInfo->addColumn( "" );
   m_viewInfo->addColumn( i18n( "Message" ) );
   m_viewInfo->setFullWidth( true );
@@ -263,7 +263,7 @@ void K3bJobProgressDialog::setupGUI()
 
 void K3bJobProgressDialog::show()
 {
-  if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "hide main window while writing", false ) )
+  if( TDEConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "hide main window while writing", false ) )
     if( TQWidget* w = kapp->mainWidget() )
       w->hide();
 
@@ -291,7 +291,7 @@ void K3bJobProgressDialog::closeEvent( TQCloseEvent* e )
       w->show();
 
     if( !m_plainCaption.isEmpty() )
-      if( KMainWindow* w = dynamic_cast<KMainWindow*>(kapp->mainWidget()) )
+      if( TDEMainWindow* w = dynamic_cast<TDEMainWindow*>(kapp->mainWidget()) )
 	w->setPlainCaption( m_plainCaption );
 
     if( m_osd ) {
@@ -332,7 +332,7 @@ void K3bJobProgressDialog::slotInfoMessage( const TQString& infoString, int type
   // set the icon
   switch( type ) {
   case K3bJob::ERROR:
-    currentInfoItem->setPixmap( 0, SmallIcon( "stop" ) );
+    currentInfoItem->setPixmap( 0, SmallIcon( "process-stop" ) );
     break;
   case K3bJob::WARNING:
     currentInfoItem->setPixmap( 0, SmallIcon( "yellowinfo" ) );
@@ -342,7 +342,7 @@ void K3bJobProgressDialog::slotInfoMessage( const TQString& infoString, int type
     break;
   case K3bJob::INFO:
   default:
-    currentInfoItem->setPixmap( 0, SmallIcon( "info" ) );
+    currentInfoItem->setPixmap( 0, SmallIcon( "application-vnd.tde.info" ) );
   }
 
   // This should scroll down (hopefully!)
@@ -457,7 +457,7 @@ void K3bJobProgressDialog::setJob( K3bJob* job )
 
     setCaption( m_job->jobDescription() );
 
-    if( KConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "Show progress OSD", true ) ) {
+    if( TDEConfigGroup( k3bcore->config(), "General Options" ).readBoolEntry( "Show progress OSD", true ) ) {
       if( !m_osd )
 	m_osd = new K3bJobProgressOSD( this, "progressosd" );
     }
@@ -504,7 +504,7 @@ void K3bJobProgressDialog::slotStarted()
   d->lastProgress = 0;
   m_timer->start( 1000 );
   m_startTime = TQTime::currentTime();
-  if( KMainWindow* w = dynamic_cast<KMainWindow*>(kapp->mainWidget()) )
+  if( TDEMainWindow* w = dynamic_cast<TDEMainWindow*>(kapp->mainWidget()) )
     m_plainCaption = w->caption();
 
   m_logFile.open();
@@ -545,7 +545,7 @@ void K3bJobProgressDialog::slotProgress( int percent )
   if( percent > d->lastProgress ) {
     d->lastProgress = percent;
     m_lastProgressUpdateTime = TQTime::currentTime();
-    if( KMainWindow* w = dynamic_cast<KMainWindow*>(kapp->mainWidget()) ) {
+    if( TDEMainWindow* w = dynamic_cast<TDEMainWindow*>(kapp->mainWidget()) ) {
       w->setPlainCaption( TQString( "(%1%) %2" ).arg(percent).arg(m_plainCaption) );
     }
 
