@@ -21,13 +21,13 @@
 
 class K3bMovixDoc;
 class K3bMovixBin;
-class KConfigBase;
+class TDEConfigBase;
 
 
 class K3bMovixOptionsWidget : public base_K3bMovixOptionsWidget
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bMovixOptionsWidget( TQWidget* parent = 0, const char* name = 0 );
@@ -37,8 +37,8 @@ class K3bMovixOptionsWidget : public base_K3bMovixOptionsWidget
   void init( const K3bMovixBin* );
   void readSettings( K3bMovixDoc* );
   void saveSettings( K3bMovixDoc* );
-  void loadConfig( KConfigBase* c );
-  void saveConfig( KConfigBase* c );
+  void loadConfig( TDEConfigBase* c );
+  void saveConfig( TDEConfigBase* c );
   void loadDefaults();
 
  private:
